==> owncloud-app-calendar-1%3A1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/es.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Habitación",
    "Unknown" : "Desconocido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "No asistir",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Estás en una zona horaria desconocida ({tz}), volviendo a  UTC",
    "New event" : "Nuevo evento",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Repeating" : "Repetición",
    "When shared show full event" : "Mostrar el evento completo al compartir",
    "When shared show only busy" : "Mostrar solamente ocupado al compartir",
    "When shared hide this event" : "Ocultar este evento al compartir",
    "Please add a title!" : "¡Por favor añade un título!",
    "Please select a calendar!" : "¡Por favor selecciona un calendario!",
    "Global" : "Global",
    "None" : "Ninguno",
    "Every day" : "Cada día",
    "Every week" : "Cada semana",
    "Every month" : "Cada mes",
    "Every year" : "Cada año",
    "never" : "nunca",
    "after" : "después de",
    "At time of event" : "A la hora del evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personal",
    "Audio" : "Audio",
    "E Mail" : "Correo electrónico",
    "Pop up" : "Ventana emergente",
    "sec" : "seg.",
    "min" : "mín.",
    "hours" : "horas",
    "days" : "días",
    "week" : "semana",
    "before" : "antes",
    "start" : "comienzo",
    "end" : "fin",
    "Editing reminders of uknown type not supported." : "Los recordatorios de edición de tipo desconocido no están soportados.",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported" : "Importado exitosamente",
    "Partially imported, 1 failure" : "Parcialmente importardo, 1 error",
    "Partially imported, {n} failures" : "Parcialmente importado, {n} errores",
    "Audio alarm" : "Sonido de alarma",
    "Pop-up" : "Ventana emergente",
    "E-Mail" : "Correo electrónico",
    "{type} {time} before the event starts" : "{type} {time} antes de que inicie el evento",
    "{type} {time} before the event ends" : "{type} {time} antes de que termine el evento",
    "{type} {time} after the event starts" : "{type} {time} después de que inicie el evento",
    "{type} {time} after the event ends" : "{type} {time} después de que termine el evento",
    "{type} at the event's start" : "{type} al inicio del evento",
    "{type} at the event's end" : "{type} al final del evento",
    "{type} at {time}" : "{type} a {time}",
    "{calendar} shared by {owner}" : "{calendar} compartido por {owner}",
    "Title of the Event" : "Título del evento",
    "starts" : "comienza",
    "ends" : "finaliza",
    "All day Event" : "Todo el día",
    "Location" : "Ubicación",
    "Delete" : "Eliminar",
    "Cancel" : "Cancelar",
    "More ..." : "Más...",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Close" : "Cerrar",
    "Description" : "Descripción",
    "Export" : "Exportar",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor contacta con el administrador y proponle que desactive la opción \"asset-pipeline.enabled'.",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Today" : "Hoy",
    "Share Calendar" : "Compartir calendario",
    "More" : "Más",
    "Edit" : "Editar",
    "CalDAV" : "CalDAV",
    "group" : "grupo",
    "New Calendar" : "Nuevo calendario",
    "Subscriptions" : "Suscripciones",
    "New Subscription" : "Nueva suscripción",
    "Url" : "Url",
    "Edit event" : "Editar evento",
    "Delete Event" : "Eliminar evento",
    "Save Event" : "Guardar evento",
    "Time" : "Hora",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "veces cada",
    "Add" : "Añadir",
    "E-Mail address of attendee" : "Correo electrónico del asistente",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor indique su e-mail en los ajustes de su cuenta para agregar asistentes",
    "from" : "desde",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "Esta regla de repetición de eventos aún no está soportada.",
    "Support for advanced rules will be added with subsequent updates." : "El soporte para reglas avanzadas se añadirá en próximas actualizaciones. ",
    "Reset repeating rule" : "Reinicializar regla de repetición",
    "Repeat every ..." : "Repetir cada...",
    "end repeat ..." : "finalizar Repetir ...",
    "times" : "veces",
    "Import Calendars" : "Importar calendario",
    "Import canceled" : "Importación cancelada",
    "Analyzing calendar" : "Analizando calendario",
    "The file contains objects incompatible with the selected calendar" : "El archivo contiene objetos incompatibles con el calendario seleccionado",
    "New calendar" : "Nuevo calendario",
    "Import scheduled" : "Importar horario",
    "Settings" : "Ajustes",
    "Import calendar" : "Importar calendario",
    "No Calendars selected for import" : "No se seleccionó un calendario para importar",
    "Primary CalDAV address" : "Direccion de calendario CalDAV primario",
    "iOS/OS X CalDAV address" : "Direccion de calendario CalDAV iOS/OSX"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-calendar-1%3A1.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/es.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Habitación",
    "Unknown" : "Desconocido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "No asistir",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Estás en una zona horaria desconocida ({tz}), volviendo a  UTC",
    "Please create a calendar first." : "Por favor, cree primero un calendario.",
    "New event" : "Nuevo evento",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Repeating" : "Repetición",
    "When shared show full event" : "Mostrar el evento completo al compartir",
    "When shared show only busy" : "Mostrar solamente ocupado al compartir",
    "When shared hide this event" : "Ocultar este evento al compartir",
    "Please add a title!" : "¡Por favor añade un título!",
    "Please select a calendar!" : "¡Por favor selecciona un calendario!",
    "Global" : "Global",
    "None" : "Ninguno",
    "Every day" : "Cada día",
    "Every week" : "Cada semana",
    "Every month" : "Cada mes",
    "Every year" : "Cada año",
    "never" : "nunca",
    "after" : "después de",
    "At time of event" : "A la hora del evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personal",
    "Audio" : "Audio",
    "E Mail" : "Correo electrónico",
    "Pop up" : "Ventana emergente",
    "sec" : "seg.",
    "min" : "mín.",
    "hours" : "horas",
    "days" : "días",
    "week" : "semana",
    "before" : "antes",
    "start" : "comienzo",
    "end" : "fin",
    "Editing reminders of uknown type not supported." : "Los recordatorios de edición de tipo desconocido no están soportados.",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported" : "Importado exitosamente",
    "Partially imported, 1 failure" : "Parcialmente importardo, 1 error",
    "Partially imported, {n} failures" : "Parcialmente importado, {n} errores",
    "Audio alarm" : "Sonido de alarma",
    "Pop-up" : "Ventana emergente",
    "E-Mail" : "Correo electrónico",
    "{type} {time} before the event starts" : "{type} {time} antes de que inicie el evento",
    "{type} {time} before the event ends" : "{type} {time} antes de que termine el evento",
    "{type} {time} after the event starts" : "{type} {time} después de que inicie el evento",
    "{type} {time} after the event ends" : "{type} {time} después de que termine el evento",
    "{type} at the event's start" : "{type} al inicio del evento",
    "{type} at the event's end" : "{type} al final del evento",
    "{type} at {time}" : "{type} a {time}",
    "{calendar} shared by {owner}" : "{calendar} compartido por {owner}",
    "Title of the Event" : "Título del evento",
    "starts" : "comienza",
    "ends" : "finaliza",
    "All day Event" : "Todo el día",
    "Location" : "Ubicación",
    "Delete" : "Eliminar",
    "Cancel" : "Cancelar",
    "More ..." : "Más...",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Close" : "Cerrar",
    "Description" : "Descripción",
    "Export" : "Exportar",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Debido a un bug de upstream, el calendario no soporta la funcionalidad de asset pipeline",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor contacta con el administrador y proponle que desactive la opción \"asset-pipeline.enabled'.",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Today" : "Hoy",
    "Share Calendar" : "Compartir calendario",
    "More" : "Más",
    "Edit" : "Editar",
    "CalDAV" : "CalDAV",
    "group" : "grupo",
    "New Calendar" : "Nuevo calendario",
    "Subscriptions" : "Suscripciones",
    "New Subscription" : "Nueva suscripción",
    "Url" : "Url",
    "Edit event" : "Editar evento",
    "Delete Event" : "Eliminar evento",
    "Save Event" : "Guardar evento",
    "Time" : "Hora",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "veces cada",
    "Add" : "Añadir",
    "E-Mail address of attendee" : "Correo electrónico del asistente",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor indique su e-mail en los ajustes de su cuenta para agregar asistentes",
    "from" : "desde",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "Esta regla de repetición de eventos aún no está soportada.",
    "Support for advanced rules will be added with subsequent updates." : "El soporte para reglas avanzadas se añadirá en próximas actualizaciones. ",
    "Reset repeating rule" : "Reinicializar regla de repetición",
    "Repeat every ..." : "Repetir cada...",
    "end repeat ..." : "finalizar Repetir ...",
    "times" : "veces",
    "Import Calendars" : "Importar calendario",
    "Import canceled" : "Importación cancelada",
    "Analyzing calendar" : "Analizando calendario",
    "The file contains objects incompatible with the selected calendar" : "El archivo contiene objetos incompatibles con el calendario seleccionado",
    "New calendar" : "Nuevo calendario",
    "Import scheduled" : "Importar horario",
    "Settings" : "Ajustes",
    "Import calendar" : "Importar calendario",
    "No Calendars selected for import" : "No se seleccionó un calendario para importar",
    "Primary CalDAV address" : "Direccion de calendario CalDAV primario",
    "iOS/OS X CalDAV address" : "Direccion de calendario CalDAV iOS/OSX"
},
"nplurals=2; plural=(n != 1);");
